@@ -121,7 +121,7 @@ RETRY_OPS = (
     MINIMUM_DELAY_RETRIES,
     MINIMUM_DELAY,
     MAXIMUM_DELAY,
-    MAXIMUM_DELA_RETRIES,
+    MAXIMUM_DELAY_RETRIES,
     LINEAR_INTERVAL,
 ) = (
     3,
