@@ -87,9 +87,8 @@ class PoolsController(base.PoolsBase):
         super(PoolsController, self).__init__(*args, **kwargs)
         self._client = self.driver.connection
         self.flavor_ctl = self.driver.flavors_controller
-        self._packer = msgpack.Packer(encoding='utf-8',
-                                      use_bin_type=True).pack
-        self._unpacker = functools.partial(msgpack.unpackb, encoding='utf-8')
+        self._packer = msgpack.Packer(use_bin_type=True).pack
+        self._unpacker = functools.partial(msgpack.unpackb)
 
     @utils.raises_conn_error
     @utils.retries_on_connection_error
